summaryrefslogtreecommitdiff
path: root/src/mongo/s/query/cluster_client_cursor_impl.h
diff options
context:
space:
mode:
authorliubov.molchanova <liubov.molchanova@mongodb.com>2023-05-17 08:16:48 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2023-05-17 10:20:42 +0000
commit87160f876c6fb94f5d03062b2caee57539ec5d8e (patch)
treeb78d9ca9e853a236e0a2f6432a6ac02dc50119cd /src/mongo/s/query/cluster_client_cursor_impl.h
parent1c390a0c50104a04cbd8ecbefb99eaf22e1bc914 (diff)
downloadmongo-87160f876c6fb94f5d03062b2caee57539ec5d8e.tar.gz
Revert "SERVER-76427: Rename $telemetry to $queryStats"
This reverts commit d646e44b7801a3e5b3230bbae7dcfe05a5ed8707.
Diffstat (limited to 'src/mongo/s/query/cluster_client_cursor_impl.h')
-rw-r--r--src/mongo/s/query/cluster_client_cursor_impl.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/s/query/cluster_client_cursor_impl.h b/src/mongo/s/query/cluster_client_cursor_impl.h
index 9d9168d6afb..ecb7535715c 100644
--- a/src/mongo/s/query/cluster_client_cursor_impl.h
+++ b/src/mongo/s/query/cluster_client_cursor_impl.h
@@ -121,7 +121,7 @@ public:
bool shouldOmitDiagnosticInformation() const final;
- std::unique_ptr<query_stats::RequestShapifier> getRequestShapifier() final;
+ std::unique_ptr<telemetry::RequestShapifier> getRequestShapifier() final;
public:
/**
@@ -186,12 +186,12 @@ private:
bool _shouldOmitDiagnosticInformation = false;
// If boost::none, telemetry should not be collected for this cursor.
- boost::optional<std::size_t> _queryStatsStoreKeyHash;
- // TODO: SERVER-73152 remove queryStatsStoreKey when RequestShapifier is used for agg.
- boost::optional<BSONObj> _queryStatsStoreKey;
+ boost::optional<std::size_t> _telemetryStoreKeyHash;
+ // TODO: SERVER-73152 remove telemetryStoreKey when RequestShapifier is used for agg.
+ boost::optional<BSONObj> _telemetryStoreKey;
// The RequestShapifier used by telemetry to shapify the request payload into the telemetry
// store key.
- std::unique_ptr<query_stats::RequestShapifier> _queryStatsRequestShapifier;
+ std::unique_ptr<telemetry::RequestShapifier> _telemetryRequestShapifier;
// Tracks if kill() has been called on the cursor. Multiple calls to kill() is an error.
bool _hasBeenKilled = false;